Class: Tablature::PartitionedTable
- Inherits:
-
Object
- Object
- Tablature::PartitionedTable
- Defined in:
- lib/tablature/partitioned_table.rb
Overview
The in-memory representation of a partitioned table definition.
This object is used internally by adapters and the schema dumper and is not intended to be used by application code. It is documented here for use by adapter gems.
Instance Attribute Summary collapse
-
#name ⇒ String
readonly
The name of the partitioned table.
-
#partition_key ⇒ String
readonly
The partition key expression.
-
#partitioning_method ⇒ Symbol
readonly
The partitioning method of the table.
-
#partitions ⇒ Array
readonly
The partitions of the table.
Instance Method Summary collapse
-
#initialize(name:, partitioning_method:, partitions: [], partition_key:) ⇒ PartitionedTable
constructor
Returns a new instance of PartitionTable.
Constructor Details
#initialize(name:, partitioning_method:, partitions: [], partition_key:) ⇒ PartitionedTable
Returns a new instance of PartitionTable.
32 33 34 35 36 37 |
# File 'lib/tablature/partitioned_table.rb', line 32 def initialize(name:, partitioning_method:, partitions: [], partition_key:) @name = name @partitioning_method = partitioning_method @partitions = partitions @partition_key = partition_key end |
Instance Attribute Details
#name ⇒ String (readonly)
The name of the partitioned table
12 13 14 |
# File 'lib/tablature/partitioned_table.rb', line 12 def name @name end |
#partition_key ⇒ String (readonly)
The partition key expression.
24 25 26 |
# File 'lib/tablature/partitioned_table.rb', line 24 def partition_key @partition_key end |
#partitioning_method ⇒ Symbol (readonly)
The partitioning method of the table
16 17 18 |
# File 'lib/tablature/partitioned_table.rb', line 16 def partitioning_method @partitioning_method end |
#partitions ⇒ Array (readonly)
The partitions of the table.
20 21 22 |
# File 'lib/tablature/partitioned_table.rb', line 20 def partitions @partitions end |